# Interactive light-weight tool to connect server by ssh

It's only a lite tool.

## Principle
Read configration from `$HOME/.ssh/config`.

## Installation
> only supports python3.

```python
pip install gotwo
```
or  
```python
python3 -m pip install gotwo -i https://pypi.python.org/simple
```

## Usages
![](https://gitee.com/echohiyang/markdown-images/raw/master/2020-03-20-%E4%BC%81%E4%B8%9A%E5%BE%AE%E4%BF%A1%E6%88%AA%E5%9B%BE_2fd0c5f3-e7d8-4346-825c-b7b05929f1e7.png)
